# HG changeset patch
# User Alpar Juttner <alpar@cs.elte.hu>
# Date 1235388615 0
# Node ID 3af83b6be1df1c4d7a3da1bb927221b375259338
# Parent  42d4b889903a37e9df65f779bd47de262cdd9ef0
Rename euler() to eulerian() (#65)

diff -r 42d4b889903a -r 3af83b6be1df lemon/euler.h
--- a/lemon/euler.h	Mon Feb 23 11:30:15 2009 +0000
+++ b/lemon/euler.h	Mon Feb 23 11:30:15 2009 +0000
@@ -228,25 +228,25 @@
   };
 
 
   ///Checks if the graph is Euler
 
   /// \ingroup graph_prop
   ///Checks if the graph is Euler. It works for both directed and undirected
   ///graphs.
   ///\note By definition, a digraph is called \e Euler if
   ///and only if it is connected and the number of its incoming and outgoing
   ///arcs are the same for each node.
   ///Similarly, an undirected graph is called \e Euler if
   ///and only if it is connected and the number of incident arcs is even
   ///for each node. <em>Therefore, there are digraphs which are not Euler, but
   ///still have an Euler tour</em>.
   ///\todo Test required
   template<class Digraph>
 #ifdef DOXYGEN
   bool
 #else
   typename enable_if<UndirectedTagIndicator<Digraph>,bool>::type
-  euler(const Digraph &g)
+  eulerian(const Digraph &g)
   {
     for(typename Digraph::NodeIt n(g);n!=INVALID;++n)
       if(countIncEdges(g,n)%2) return false;
@@ -255,7 +255,7 @@
   template<class Digraph>
   typename disable_if<UndirectedTagIndicator<Digraph>,bool>::type
 #endif
-  euler(const Digraph &g)
+  eulerian(const Digraph &g)
   {
     for(typename Digraph::NodeIt n(g);n!=INVALID;++n)
       if(countInArcs(g,n)!=countOutArcs(g,n)) return false;
@@ -228,25 +228,25 @@
 
 
-  ///Checks if the graph is Euler
+  ///Checks if the graph is Eulerian
 
   /// \ingroup graph_prop
@@ -228,25 +228,25 @@
 
   /// \ingroup graph_prop
-  ///Checks if the graph is Euler. It works for both directed and undirected
+  ///Checks if the graph is Eulerian. It works for both directed and undirected
   ///graphs.
@@ -228,25 +228,25 @@
   ///graphs.
-  ///\note By definition, a digraph is called \e Euler if
+  ///\note By definition, a digraph is called \e Eulerian if
   ///and only if it is connected and the number of its incoming and outgoing
   ///arcs are the same for each node.
@@ -228,25 +228,25 @@
   ///and only if it is connected and the number of its incoming and outgoing
   ///arcs are the same for each node.
-  ///Similarly, an undirected graph is called \e Euler if
+  ///Similarly, an undirected graph is called \e Eulerian if
   ///and only if it is connected and the number of incident arcs is even
@@ -228,25 +228,25 @@
   ///and only if it is connected and the number of incident arcs is even
-  ///for each node. <em>Therefore, there are digraphs which are not Euler, but
-  ///still have an Euler tour</em>.
+  ///for each node. <em>Therefore, there are digraphs which are not Eulerian,
+  ///but still have an Euler tour</em>.
   ///\todo Test required
   template<class Digraph>